pub fn collect_column_options(
column_options: Option<&ColumnOptions>,
) -> MetadataExpand description
Collect the ColumnOptions into the Metadata that can be used in, for example, ColumnSchema.
pub fn collect_column_options(
column_options: Option<&ColumnOptions>,
) -> MetadataCollect the ColumnOptions into the Metadata that can be used in, for example, ColumnSchema.